@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -13,9 +13,9 @@
 
 #include "abstractindexer.h"
 
-#include <KMime/Message>
 #include <Collection>
 #include <Item>
+#include <KMime/Message>
 
 class AkonotesIndexer : public AbstractIndexer
 {
@@ -25,7 +25,7 @@ public:
      * should be stored
      */
     explicit AkonotesIndexer(const QString &path);
-    ~AkonotesIndexer();
+    ~AkonotesIndexer() override;
 
     QStringList mimeTypes() const override;
 
@@ -35,6 +35,7 @@ public:
     void remove(const Akonadi::Item &item) override;
     void remove(const Akonadi::Collection &collection) override;
     void move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from, Akonadi::Collection::Id to) override;
+
 private:
     void processPart(KMime::Content *content, KMime::Content *mainContent);
     void process(const KMime::Message::Ptr &msg);
