@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,8 +9,10 @@
 
 #include <QSyntaxHighlighter>
 
-namespace Akonadi {
-namespace Search {
+namespace Akonadi
+{
+namespace Search
+{
 class Rule
 {
 public:
