@@ -13,9 +13,12 @@
 
 #include "resultiterator.h"
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class Q_DECL_HIDDEN ResultIterator::Private
 {
 public:
